/*
 * Copyright (c) 2019 Razeware LLC
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * Notwithstanding the foregoing, you may not use, copy, modify, merge, publish,
 * distribute, sublicense, create a derivative work, and/or sell copies of the
 * Software in any work that is designed, intended, or marketed for pedagogical or
 * instructional purposes related to programming, coding, application development,
 * or information technology.  Permission for such use, copying, modification,
 * merger, publication, distribution, sublicensing, creation of derivative works,
 * or sale is expressly withheld.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 */
import 'package:flutter/material.dart';

import 'dart:convert';

import 'package:get2itlib/Utils/httpResponse.dart';

import 'package:get2itlib/src/OpenPWS.dart';



class IMWAPI {
  String iawAppURL = "";
  String appID = "";
  IMWAPI(String baseURL, appID){
    this.iawAppURL = baseURL + "/PIP";
    this.appID = appID;
  }

  Future<dynamic> openPWS(
      BuildContext context, String userID, String password, String eso, String regString, String deviceID) async {
    var r = await Requests.get(
        '$iawAppURL?request=openPWS&appID=$appID&deviceName=MA&regString=$regString&deviceID=$deviceID&deviceOS=null&pwsUserPwd=$password&pwsUserID=$userID&lat=40.7128&long=-74.006&eso=$eso');
    dynamic openPWSResp = r.content();
    OpenPWS openPWS = OpenPWS.fromJson(jsonDecode(openPWSResp));
    Navigator.pushNamed(context, "/" + openPWS.response.output.session.tmplt, arguments: openPWS.response.output.pages);
    return openPWSResp;
  }

  Future<dynamic> openPWSSpl(
      BuildContext context, String userID, String password, String eso, String regString, String deviceID) async {
    var r = await Requests.get(
        '$iawAppURL?request=openPWS&appID=$appID&deviceName=MA&regString=$regString&deviceID=$deviceID&deviceOS=null&pwsUserPwd=$password&pwsUserID=$userID&lat=40.7128&long=-74.006&eso=$eso');
    dynamic openPWSResp = r.content();
    OpenPWS openPWS = OpenPWS.fromJson(jsonDecode(openPWSResp));
    return openPWS;
  }

  Future<dynamic> execSrv(BuildContext context, String srvRef ) async {
    var r = await Requests.get('$iawAppURL?request=execService&srvRef=$srvRef&long=-73.9878531&lat=40.7484405');
    dynamic execSrvResp = jsonDecode(r.content());
    Navigator.pushNamed(context, "/" + execSrvResp["response"]["output"]["delTmplt"], arguments: execSrvResp);
    return execSrvResp;
  }

  Future<dynamic> execSrvSpl(String srvRef ) async {
    var r = await Requests.get('$iawAppURL?request=execService&srvRef=$srvRef&long=-73.9878531&lat=40.7484405');
    dynamic execSrvResp = jsonDecode(r.content());
    return execSrvResp;
  }

  Future<dynamic> execRltdSrv(BuildContext context, String srvRef, String parSrvObjRef, int selectedOffset) async {
    var r = await Requests.get('$iawAppURL?request=execRltdSrv&slctdOffsets=&srvRef=$srvRef&parentSrvObjRef=$parSrvObjRef&long=-73.9878531&lat=40.7484405&');
    dynamic execSrvResp = jsonDecode(r.content());
    Navigator.pushNamed(context, "/" + execSrvResp["response"]["output"]["delTmplt"], arguments: execSrvResp);
  }

  Future<dynamic> execRltdSrvSpl(BuildContext context, String srvRef, String parSrvObjRef, int selectedOffset) async {
    var r = await Requests.get('$iawAppURL?request=execRltdSrv&slctdOffsets=&srvRef=$srvRef&parentSrvObjRef=$parSrvObjRef&long=-73.9878531&lat=40.7484405&');
    dynamic execSrvResp = jsonDecode(r.content());
    return execSrvResp;
  }

}

